{% load i18n static coop_bar_tags coop_navigation %}
<!DOCYTPE HTML>
<!-- paulirish.com/2008/conditional-stylesheets-vs-css-hacks-answer-neither/ -->
<!--[if lt IE 7 ]> <html class="ie6" lang="en"> <![endif]-->
<!--[if IE 7 ]>    <html class="ie7" lang="en"> <![endif]-->
<!--[if IE 8 ]>    <html class="ie8" lang="en"> <![endif]-->
<!--[if (gte IE 9)|!(IE)]><!--> <html class="" lang="fr"> <!--<![endif]-->
<head>
  <meta charset="utf-8">

  <!-- Always force latest IE rendering engine (even in intranet) & Chrome Frame
       Remove this if you use the .htaccess -->
    <meta http-equiv="X-UA-Compatible" content="IE=edge,chrome=1">

    <title>{% block meta_title %}{% endblock %}{% if site_title %} | {{ site_title }}{% endif %}</title>
    <meta name="description" content="">
    <meta name="author" content="{{site_author}}">
    <!-- Mobile viewport optimized: j.mp/bplateviewport -->
    <meta name="viewport" content="width=device-width, initial-scale=1.0">

    <!-- Place favicon.ico & apple-touch-icon.png in the root of your domain and delete these references -->
    <link rel="shortcut icon" href="/favicon.ico">
    <link rel="apple-touch-icon" href="/apple-touch-icon.png">
    

    {% block jquery_declaration %}
    <script type="text/javascript" charset="utf-8" src="{{ STATIC_URL }}js/jquery-1.6.2.min.js"></script>
    {% endblock %}
    
    <!-- CSS: implied media="all" -->
    <link rel="stylesheet" href="{{ STATIC_URL }}css/html5.css?v=2">
    <link rel="stylesheet" href="{{ STATIC_URL }}css/normalize.css" type="text/css" />
    <link rel="stylesheet" href="{{ STATIC_URL }}css/960.css" type="text/css" />
    <link rel="stylesheet" href="{{ STATIC_URL }}css/style.css" type="text/css" />

    <link href='http://fonts.googleapis.com/css?family=Droid+Sans:regular,bold' rel='stylesheet' type='text/css'>
    <link href='http://fonts.googleapis.com/css?family=PT+Sans+Narrow:700|Nobile:400,400italic,700' rel='stylesheet' type='text/css'>
    
    <script src="{{ STATIC_URL }}js/modernizr.js"></script>
   <!-- <script type="text/javascript" src="{{ STATIC_URL }}js/jquery.pageslide.min.js"></script>-->
    
    {% coop_bar_headers %}
    {% block extra_head %}{% endblock %}
    
    
    
    
</head>
<body id="{% block body_id %}{% endblock %}">
{% coop_bar %}
<div id="container">

<header class="container_12">
    <div id="the_dot" style="opacity: 1;">
    <a href="/">
       <div class="dot_pulse">&nbsp;</div>
       <div class="dot">&nbsp;</div>
      </a>
    </div>
    <h1><a href="/" title="Accueil">{{site_title}}</a></h1>
    
</header>

<div id="main" role="main" class="container_12 clearfix">
  {% block navigation %}
  <nav>
      <ul id="nav">{% navigation_as_nested_ul %}</ul>
  </nav>
  {% endblock %}
    
      {% block document %}
        {% block title %}{% endblock %}
        {% block content %}{% endblock %}        
      {% endblock %}


</div>

<footer class="container_12 clearfix">
    <div>
        {% block footer %}        


        {% endblock %}
        <a href="http://django-fr.org/">
            <img id="django" border="0" src="{{ STATIC_URL }}img/djangoproject.gif"/>
        </a>
    </div>
</footer>

</div>

{% comment %}
<!-- Grab Google CDN's jQuery, with a protocol relative URL; fall back to local if necessary -->
<script src="//ajax.googleapis.com/ajax/jquery/1.5.1/jquery.js"></script>
<script>window.jQuery || document.write("<script src='{{ STATIC_URL }}js/jquery-1.5.2.min.js'>\x3C/script>")</script>

{% endcomment %}

<script type="text/javascript">
$(function(){
    
    //$("#perso").pageSlide({width:'350px', direction:'right'});
    {% block jquery %}{% endblock %}
});


</script>

<script type="text/javascript"><!--//--><![CDATA[//><!--
sfHover = function() {
    var sfEls = document.getElementById("nav").getElementsByTagName("LI");
    for (var i=0; i<sfEls.length; i++) {
        sfEls[i].onmouseover=function() {
            this.className+=" sfhover";
        }
        sfEls[i].onmouseout=function() {
            this.className=this.className.replace(new RegExp(" sfhover\\b"), "");
        }
    }
}
if (window.attachEvent) window.attachEvent("onload", sfHover);
//--><!]]></script>


</body>
</html>

