/* @override http://localhost:8000/static/css/style.css */

body {
	background-color: #f3ece6;
	font-family: Nobile, Lucida, Verdana, sans-serif;
}

#container{
	position: relative;
}

header {
	height: 80px;
	position: relative;
}

div#main {
	border-top-style: none;
	border-bottom-style: none;
	background-color: white;
	padding-bottom: 20px;
	border-left: 1px solid #d5d5d5;
	border-right: 1px solid #d5d5d5;

}

span.unicon {
	display: inline-block;
	margin-top: -0.2em;
	height: 1em;
	margin-right: 0.2em;
	position: relative;
	top: 0.1em;
	font-size: 1.4em;
}

#content {
	padding-bottom: 20px;
	padding-top: 20px;
	min-height: 400px;
}

p {
	margin-bottom: 1em;
}

table td {
	border-collapse: collapse;
	border: 1px solid silver;
}

h1,h2,h3,h4,h5,h6, nav {
	font-family: "Cabin", "PT Sans Narrow", "Trebuchet MS", Trebuchet, Tahoma, Arial;
}

h1 {
	padding-top: 19px;
	padding-left: 90px;
	font-size: 2.5em;
}



header h1 a, header h1 a:visited {
	color: #6c6c6c;
	text-decoration: none;
}

header h1 a:active {
	background-color: white;
}

h2 {
	font-size: 2.7em;
}

h3 {
	font-size: 2.3em;
	padding-top: 10px;
	margin-bottom: 10px;
}

h4 {
	font-weight: normal;
	font-style: normal;
	font-size: 1.3em;
	background-color: #ebf7f6;
	padding: 4px 4px 2px 8px;
	border: 1px solid #d5d5e8;
	margin-bottom: 10px;
	margin-top: 10px;
	-webkit-border-radius: 4px;
	-moz-border-radius: 4px;
	border-radius: 4px;
	background: #FFFFFF;
	background: -webkit-gradient(linear, 0 0, 0 bottom, from(#FFFFFF), to(#A8D7E1));
	background: -webkit-linear-gradient(#FFFFFF, #A8D7E1);
	background: -moz-linear-gradient(#FFFFFF, #A8D7E1);
	background: -ms-linear-gradient(#FFFFFF, #A8D7E1);
	background: -o-linear-gradient(#FFFFFF, #A8D7E1);
	background: linear-gradient(#FFFFFF, #A8D7E1);
	text-shadow: #f8f8f8 1px 1px 0;
}

#content {
	font-size: 1.1em;
	position: relative;
}

nav {
	position: relative;
}

#perso {
	position: absolute;
	top: 12px;
	right: 20px;
	font-size: 16px;
	font-weight: bold;
	text-decoration: underline;
	color: #fffeff;
}

#pageslide-slide-wrap {
	background-color: #797979;
}

#ppanel h3 {
	text-align: center;
	color: #fffeff;
}

#tags {
	list-style-type: none;
	margin: 0;
	padding: 0;
}

#tags li {
	float: left;
	padding-bottom: 5px;
	padding-right: 9px;
}

#tags a {
	display: inline-block;
	border: 1px solid #cececf;
	background-color: #ededed;
	margin-top: 4px;
	padding: 2px 9px 3px;
	text-decoration: none;
	color: #4f4f4f;
	font: bold 15px "PT Sans Narrow","Trebuchet MS", Trebuchet, Tahoma, Arial;
}

#tags a:hover {
	background: #FDFCF7;
	background: -webkit-gradient(linear, 0 0, 0 bottom, from(#FDFCF7), to(#F0DA2D));
	background: -webkit-linear-gradient(#FDFCF7, #F0DA2D);
	background: -moz-linear-gradient(#FDFCF7, #F0DA2D);
	background: -ms-linear-gradient(#FDFCF7, #F0DA2D);
	background: -o-linear-gradient(#FDFCF7, #F0DA2D);
	background: linear-gradient(#FDFCF7, #F0DA2D);
	border-color: #ffad4a;
	color: black;
}

.tag_icon_list {
	text-transform: uppercase;
	list-style-type: none;
	padding-left: 0;
}

.tag_icon_list li {
	margin-left: 0;
	padding-left: 70px;
	height: 60px;
	vertical-align: middle;
	position: relative;
	padding-top: 10px;
}

.tag_icon_list li .org_icon {
	position: absolute;
	top: 0;
	left: 0;
}

/* @group Basic CSS Menu */

/* 
http://www.htmldog.com/articles/suckerfish/dropdowns/
Laisser tranquille , surclasser ailleurs 
*/

#nav, #nav ul {
	padding: 0;
	margin: 0;
	list-style: none;
	position: relative;
}

#nav a {
	display: block;
	width: 12em;
}

#nav li {
	float: left;
	width: 12em;
	position: relative;
}

#nav li ul {
	position: absolute;
	width: 12em;
	left: -999em;
	z-index: 1000;
}

#nav li:hover ul {
	left: auto;
}

#nav li:hover ul, #nav li.sfhover ul {
	left: auto;
}

/* Mulit-level*/

#nav li ul ul {
	margin: -1em 0 0 12em;
}

#nav, #nav ul {
	padding: 0;
	margin: 0;
	list-style: none;
	line-height: 1;
}

#nav li:hover ul ul, #nav li.sfhover ul ul {
	left: -999em;
}

#nav li:hover ul, #nav li li:hover ul, #nav li.sfhover ul, #nav li li.sfhover ul {
	left: auto;
}

/* @end */

/* @group Personnalisation Menu CSS */

#nav {
	background-color: #f5524a;
	border: 1px solid #bc717f;
	width: 100%;
	height: 3.2em;
	background-color: #f7797c;
	border-right-style: none;
	border-left-style: none;
}

#nav li a {
	position: relative;
	text-decoration: none;
	color: #feffff;
	padding-left: 0.5em;
	font-weight: bold;
	font-size: 1.6em;
}

#nav, #nav ul {
	padding: 0;
	line-height: 2;
}

#nav li ul ul {
	margin: -2.4em 0 0 12em;
}

#nav > li {
	height: 100%;
	border-right: 1px solid #d3604c;
}

#nav ul {
	background-color: #f7797c;
	border: 1px solid #cd887f;
	border-top-style: none;
}

#nav ul > li a {
	font-size: 1.2em;
}

#nav ul ul > li a {
	font-size: 1.1em;
}

#nav li ul li:hover {
	background-color: #fbfcc2;
}

#nav li ul li:hover a {
	color: #424242;
}

/* @end */

/* @group hCard */

div.vcard {
	width: 300px;
	padding: 30px;
	background: -webkit-gradient(linear, left top, left bottom, from(#fff), to(#ebd8a0));
	background: -moz-linear-gradient(top,  #fff,  #ebd8a0);
	filter: progid:DXImageTransform.Microsoft.gradient(startColorstr='#fff', endColorstr='#ebd8a0');
	border-radius: 16px;
	-moz-border-radius: 16px;
	-webkit-border-radius: 16px;
	box-shadow: 1px 2px 5px #333;
	-moz-box-shadow: 1px 2px 5px #333;
	-webkit-box-shadow: 1px 2px 5px #333;
	margin-top: 20px;
}

div.vcard abbr {
	font-size: 12px;
	color: #4f4f4f;
	margin-left: 3px;
	margin-right: 3px;
}

.vcard .fn.n {
	font-weight: bold;
	font-size: 1.2em;
}

.vcard a {
	display: inline-block;
	text-decoration: none;
	color: #141ea2;
}

.vcard .tel, 
.vcard .adr, 
.vcard .email {
	margin-top: 10px;
}

#mod_profil_link {
	margin-top: 20px;
	font-weight: bold;
	font-size: 14px;
	margin-bottom: 0;
	padding-bottom: 0;
	text-align: right;
}

.client #id_adresse {
	width: 250px;
	font-size: 14px;
	height: 80px;
}

/* @end */

/* @group footer */

footer {
	border-top: 1px solid #bababa;
}

footer div {
	text-align: right;
	padding: 20px 10px 30px;
}

footer ul {
	margin: 0 30px;
}

footer ul ul {
	margin: 0;
}

footer li {
	float: left;
}

footer li li {
	width: 100px;
	clear: both;
	margin: 5px;
	border: 1px solid #333;
	background: #555;
	padding: 5px 10px;
	border-right: 0;
	border-bottom: 0;
}

footer a {
	color: #eee;
	text-decoration: none;
}

/* @end */

/* @group form */

form.form {
	width: 90%;
	border-radius: 16px;
	-moz-border-radius: 16px;
	-webkit-border-radius: 16px;
	padding: 20px;
	border: 3px solid #c5c5c5;
}

form.form label {
	width: 200px;
	vertical-align: middle;
}

form.form input {
	width: 300px;
	padding: 4px;
	font-size: 16px;
	vertical-align: middle;
}

form.form select {
	font-size: 16px;
}

form.form textarea {
	font-size: 14px;
	line-height: 1.2em;
}

.form {
	background: #eee;
	border-bottom: 1px solid #ccc;
	float: left;
}

.form li ul,
.form li li {
	display: inline;
}

.form li label {
	width: 30%;
	float: left;
}

.form li li label {
	width: auto;
	float: none;
	cursor: pointer;
}

/* @end */

/* @group login */

#search ul {
	padding-left: 0;
}

div.login_warning {
	background: url(/site_media/img/cross.png) no-repeat 10px 25px;
	font-weight: bold;
	font-size: 15px;
	padding: 20px 20px 0 60px;
	color: #920000;
	line-height: 18px;
}

div.login_warning ul {
	list-style-type: none;
	margin-top: 20px;
}

div.login_warning li {
	vertical-align: middle;
	font-weight: bold;
	display: block;
	width: 450px;
	margin-bottom: 10px;
	height: 30px;
}

div.login_warning li img {
	position: relative;
	float: left;
	top: -5px;
	margin-right: 10px;
}

fieldset.client label {
	width: 200px;
	display: inline-block;
	vertical-align: middle;
	text-align: right;
	padding-right: 10px;
}

.client input[type=text],
.client input[type=password] {
	height: 25px;
	vertical-align: middle;
	font-size: 14px;
	width: 250px;
	padding: 4px;
}

/* @end */

/* @group Commentaires */

#comment_form {
	padding-left: 17px;
}

p.comm_title {
	background: url(/static/img/comm_title.jpg) no-repeat;
	padding: 15px 12px 15px 80px;
	color: #5c5c5c;
}

p.comm_title b {
	font: 22px/22px serif;
	color: #80a839;
	letter-spacing: 1px;
	top: -5px;
	position: relative;
}

#comment_form label {
	display: block;
	font-size: 15px;
	margin-bottom: 9px;
	font-weight: bold;
	line-height: 22px;
}

#comment_form label span {
	color: #9c9c9c;
	font-weight: normal;
	font-style: normal;
	font-size: 13px;
	display: block;
	margin-top: 10px;
	margin-bottom: -5px;
}

#comment_form input.submit-post {
	background-color: #dfc820;
	border: 4px outset #f5db26;
	padding: 0 10px 3px;
	position: relative;
	top: -9px;
	border-radius: 4px;
	-moz-border-radius: 4px;
	-webkit-border-radius: 4px;
	font: bold 12px Nobile, Lucida, Verdana, sans-serif;
}

textarea#id_comment,
form.survey textarea {
	font: 0.9em 'Droid Sans', arial, serif;
	height: 97px;
	padding: 7px;
	color: #363636;
	font-size: 15px;
	width: 95%;
	border: 2px solid #a5a5a5;
	background-image: url(/static/img/petits-carreaux.jpg);
	overflow-y: auto;
	margin-bottom: 5px;
}

div.comment {
	border-bottom: 2px solid #aaa;
	padding-bottom: 15px;
	padding-left: 20px;
}

div.comment p {
	font-size: 13px;
	color: #9c9c9c;
	margin-left: -20px;
}

div.comment p a {
	text-decoration: none;
	color: #5c83b8;
}

div.comment p a:hover {
	text-decoration: underline;
}

ul.errorlist {
	list-style-type: square;
	margin: 0;
	padding: 0 0 0 20px;
	font-weight: bold;
	color: #cd0818;
	display: inline-block;
}

/* @end */

/* @group initiative */

p.statut {
	font-weight: bold;
	color: #929292;
}

.tel {
	font: bold 18px "PT Sans Narrow","Trebuchet MS", Trebuchet, Tahoma, Arial;
}

.url a {
	text-decoration: none;
	font-size: 13px;
	line-height: 24px;
	color: #f9650f;
}

.logo {
	text-align: center;
}

ul.membres {
	padding-left: 5px;
	display: inline-block;
	position: relative;
	margin: 0;
}

ul.membres li {
	list-style-type: none;
	padding-left: 0;
	margin-left: 0;
	border: 1px solid #dadada;
	height: 48px;
	position: relative;
	padding: 5px;
	margin-bottom: 7px;
	width: 278px;
	float: left;
	margin-right: 10px;
	display: inline-block;
}

ul.membres li p {
	padding-left: 60px;
	position: relative;
	margin-top: 8px;
	font-size: 0.9em;
}

ul.membres li img {
	float: left;
}

ul.membres li a {
	text-decoration: none;
}

a.role {
	color: #555;
}

a.role:hover {
	color: #265aff;
}

div.adresse {
	padding: 5px;
	color: gray;
}

div.main_location {
	border-style: solid;
	color: black;
}

div.postal {
	margin-left: 10px;
}

.coordonnees {
	
}

.rel_type {
	font-size: 12px;
}

ul.relations {
	padding: 0;
	margin: 10px 0 0;
	position: relative;
	display: inline-block;
}

ul.relations li {
	list-style-type: none;
	width: 52px;
	float: left;
	height: 52px;
	margin-right: 8px;
	margin-bottom: 8px;
}

.org_icon {
	display: inline-block;
	width: 54px;
	height: 54px;
	border: 1px solid #eaeaea;
	position: relative;
}

.org_icon > a > img {
	position: relative;
	top: 2px;
	left: 2px;
}

.org_icon div {
	position: absolute;
	top: 2px;
	left: 2px;
	display: none;
}

ul.relations li a {
	border-style: none;
}

/* @end */

p.special_Case {
	font-weight: bold;
	padding: 10px;
	border: 2px solid #f9c641;
	background-color: #f5ffb7;
	float: right;
	position: absolute;
	right: 0;
	width: 200px;
	top: 0;
}

/* @group tipsy */

.tipsy {
	font-size: 10px;
	position: absolute;
	padding: 5px;
	z-index: 100000;
}

.tipsy-inner {
	background-color: #000;
	color: #FFF;
	max-width: 200px;
	padding: 5px 8px 4px 8px;
	text-align: center;
}

/* Rounded corners */

.tipsy-inner {
	border-radius: 3px;
	-moz-border-radius: 3px;
	-webkit-border-radius: 3px;
}

/* Uncomment for shadow */

/*.tipsy-inner { box-shadow: 0 0 5px #000000; -webkit-box-shadow: 0 0 5px #000000; -moz-box-shadow: 0 0 5px #000000; }*/

.tipsy-arrow {
	position: absolute;
	width: 0;
	height: 0;
	line-height: 0;
	border: 5px dashed #000;
}

/* Rules to colour arrows */

.tipsy-arrow-n {
	border-bottom-color: #000;
}

.tipsy-arrow-s {
	border-top-color: #000;
}

.tipsy-arrow-e {
	border-left-color: #000;
}

.tipsy-arrow-w {
	border-right-color: #000;
}

.tipsy-n .tipsy-arrow {
	top: 0px;
	left: 50%;
	margin-left: -5px;
	border-bottom-style: solid;
	border-top: none;
	border-left-color: transparent;
	border-right-color: transparent;
}

.tipsy-nw .tipsy-arrow {
	top: 0;
	left: 10px;
	border-bottom-style: solid;
	border-top: none;
	border-left-color: transparent;
	border-right-color: transparent;
}

.tipsy-ne .tipsy-arrow {
	top: 0;
	right: 10px;
	border-bottom-style: solid;
	border-top: none;
	border-left-color: transparent;
	border-right-color: transparent;
}

.tipsy-s .tipsy-arrow {
	bottom: 0;
	left: 50%;
	margin-left: -5px;
	border-top-style: solid;
	border-bottom: none;
	border-left-color: transparent;
	border-right-color: transparent;
}

.tipsy-sw .tipsy-arrow {
	bottom: 0;
	left: 10px;
	border-top-style: solid;
	border-bottom: none;
	border-left-color: transparent;
	border-right-color: transparent;
}

.tipsy-se .tipsy-arrow {
	bottom: 0;
	right: 10px;
	border-top-style: solid;
	border-bottom: none;
	border-left-color: transparent;
	border-right-color: transparent;
}

.tipsy-e .tipsy-arrow {
	right: 0;
	top: 50%;
	margin-top: -5px;
	border-left-style: solid;
	border-right: none;
	border-top-color: transparent;
	border-bottom-color: transparent;
}

.tipsy-w .tipsy-arrow {
	left: 0;
	top: 50%;
	margin-top: -5px;
	border-right-style: solid;
	border-left: none;
	border-top-color: transparent;
	border-bottom-color: transparent;
}

/* @end */

/* @group dotpulse */

div#the_dot {
	text-align: right;
	display: block;
	position: absolute;
	z-index: 0;
	top: 29px;
	left: 60px;
}

div#the_dot a {
	display: block;
	text-decoration: none;
}

div#the_dot div.dot_pulse {
	margin: 0 auto;
	width: 70px;
	height: 70px;
	border-radius: 100px;
	position: absolute;
	right: -35px;
	top: -35px;
	z-index: 10;
	background-color: transparent;
	border: 10px solid #1f6ae1;
	-webkit-animation-name: dotPulse;
	-moz-animation-name: dotPulse;
	-webkit-animation-duration: 2s;
	-moz-animation-duration: 2s;
	-webkit-animation-iteration-count: infinite;
	-moz-animation-iteration-count: infinite;
	-webkit-animation-timing-function: linear;
	-moz-animation-timing-function: linear;
	opacity: 0.2;
	border-top-left-radius: 100px 100px;
	border-top-right-radius: 100px 100px;
	border-bottom-right-radius: 100px 100px;
	border-bottom-left-radius: 100px 100px;
}

div#the_dot div.dot {
	margin: 0 auto;
	width: 20px;
	height: 20px;
	border-radius: 20px;
	-webkit-border-radius: 20px;
	position: absolute;
	top: -5px;
	right: -5px;
	background-color: #fdf792;
	z-index: 50;
	border: 5px solid #ddb283;
}


/* 
    This animation inspired by Panic's awesome, amazing Transmit features page:
    http://www.panic.com/transmit/
*/

@-webkit-keyframes 'dotPulse' {
	0% {
		-webkit-transform: scale(0);
	opacity: 0;
}

8% {
	-webkit-transform: scale(0);
	opacity: 0;
}

15% {
	-webkit-transform: scale(0.1);
	opacity: 0.8;
}

30% {
	-webkit-transform: scale(0.5);
	opacity: 0.2;
}

100% {
	opacity: 0;
	border: 10px solid #ffffff;
	-webkit-transform: scale(1);
}

}


@-moz-keyframes dotPulse {
	0% {
		-moz-transform: scale(0);
	opacity: 0;
}

8% {
	-moz-transform: scale(0);
	opacity: 0;
}

15% {
	-moz-transform: scale(0.1);
	opacity: 0.8;
}

30% {
	-moz-transform: scale(0.5);
	opacity: 0.2;
}

100% {
	opacity: 0;
	border: 10px solid #ffffff;
	-moz-transform: scale(1);
}

/* @end */